@@ -2,6 +2,7 @@ import asyncio
 import builtins
 import contextlib
 import datetime
+import io
 import logging
 import os
 import pathlib
@@ -73,6 +74,31 @@ def check_dir(dir, *, files=None, size=None):
             seen.add(filepath)
 
 
+class StubStream(io.StringIO):
+    def fileno(self):
+        return 1
+
+
+class StreamIsattyTrue(StubStream):
+    def isatty(self):
+        return True
+
+
+class StreamIsattyFalse(StubStream):
+    def isatty(self):
+        return False
+
+
+class StreamIsattyException(StubStream):
+    def isatty(self):
+        raise RuntimeError
+
+
+class StreamFilenoException(StreamIsattyTrue):
+    def fileno(self):
+        raise RuntimeError
+
+
 @contextlib.contextmanager
 def default_threading_excepthook():
     if not hasattr(threading, "excepthook"):
@@ -102,6 +128,7 @@ def check_env_variables():
                 "A Loguru environment variable has been detected "
                 "and may interfere with the tests: '%s'" % var,
                 RuntimeWarning,
+                stacklevel=1,
             )
 
 
