@@ -1,7 +1,5 @@
 import pytest
-from colorama import Back as B
-from colorama import Fore as F
-from colorama import Style as S
+from colorama import Back, Fore, Style
 
 from .conftest import parse
 
@@ -9,12 +7,12 @@ from .conftest import parse
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<bold>1</bold>", S.BRIGHT + "1" + S.RESET_ALL),
-        ("<dim>1</dim>", S.DIM + "1" + S.RESET_ALL),
-        ("<normal>1</normal>", S.NORMAL + "1" + S.RESET_ALL),
-        ("<b>1</b>", S.BRIGHT + "1" + S.RESET_ALL),
-        ("<d>1</d>", S.DIM + "1" + S.RESET_ALL),
-        ("<n>1</n>", S.NORMAL + "1" + S.RESET_ALL),
+        ("<bold>1</bold>", Style.BRIGHT + "1" + Style.RESET_ALL),
+        ("<dim>1</dim>", Style.DIM + "1" + Style.RESET_ALL),
+        ("<normal>1</normal>", Style.NORMAL + "1" + Style.RESET_ALL),
+        ("<b>1</b>", Style.BRIGHT + "1" + Style.RESET_ALL),
+        ("<d>1</d>", Style.DIM + "1" + Style.RESET_ALL),
+        ("<n>1</n>", Style.NORMAL + "1" + Style.RESET_ALL),
     ],
 )
 def test_styles(text, expected):
@@ -24,10 +22,10 @@ def test_styles(text, expected):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<RED>1</RED>", B.RED + "1" + S.RESET_ALL),
-        ("<R>1</R>", B.RED + "1" + S.RESET_ALL),
-        ("<LIGHT-GREEN>1</LIGHT-GREEN>", B.LIGHTGREEN_EX + "1" + S.RESET_ALL),
-        ("<LG>1</LG>", B.LIGHTGREEN_EX + "1" + S.RESET_ALL),
+        ("<RED>1</RED>", Back.RED + "1" + Style.RESET_ALL),
+        ("<R>1</R>", Back.RED + "1" + Style.RESET_ALL),
+        ("<LIGHT-GREEN>1</LIGHT-GREEN>", Back.LIGHTGREEN_EX + "1" + Style.RESET_ALL),
+        ("<LG>1</LG>", Back.LIGHTGREEN_EX + "1" + Style.RESET_ALL),
     ],
 )
 def test_background_colors(text, expected):
@@ -37,10 +35,10 @@ def test_background_colors(text, expected):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<yellow>1</yellow>", F.YELLOW + "1" + S.RESET_ALL),
-        ("<y>1</y>", F.YELLOW + "1" + S.RESET_ALL),
-        ("<light-white>1</light-white>", F.LIGHTWHITE_EX + "1" + S.RESET_ALL),
-        ("<lw>1</lw>", F.LIGHTWHITE_EX + "1" + S.RESET_ALL),
+        ("<yellow>1</yellow>", Fore.YELLOW + "1" + Style.RESET_ALL),
+        ("<y>1</y>", Fore.YELLOW + "1" + Style.RESET_ALL),
+        ("<light-white>1</light-white>", Fore.LIGHTWHITE_EX + "1" + Style.RESET_ALL),
+        ("<lw>1</lw>", Fore.LIGHTWHITE_EX + "1" + Style.RESET_ALL),
     ],
 )
 def test_foreground_colors(text, expected):
@@ -50,28 +48,43 @@ def test_foreground_colors(text, expected):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<b>1</b><d>2</d>", S.BRIGHT + "1" + S.RESET_ALL + S.DIM + "2" + S.RESET_ALL),
-        ("<b>1</b>2<d>3</d>", S.BRIGHT + "1" + S.RESET_ALL + "2" + S.DIM + "3" + S.RESET_ALL),
+        (
+            "<b>1</b><d>2</d>",
+            Style.BRIGHT + "1" + Style.RESET_ALL + Style.DIM + "2" + Style.RESET_ALL,
+        ),
+        (
+            "<b>1</b>2<d>3</d>",
+            Style.BRIGHT + "1" + Style.RESET_ALL + "2" + Style.DIM + "3" + Style.RESET_ALL,
+        ),
         (
             "0<b>1<d>2</d>3</b>4",
-            "0" + S.BRIGHT + "1" + S.DIM + "2" + S.RESET_ALL + S.BRIGHT + "3" + S.RESET_ALL + "4",
+            "0"
+            + Style.BRIGHT
+            + "1"
+            + Style.DIM
+            + "2"
+            + Style.RESET_ALL
+            + Style.BRIGHT
+            + "3"
+            + Style.RESET_ALL
+            + "4",
         ),
         (
             "<d>0<b>1<d>2</d>3</b>4</d>",
-            S.DIM
+            Style.DIM
             + "0"
-            + S.BRIGHT
+            + Style.BRIGHT
             + "1"
-            + S.DIM
+            + Style.DIM
             + "2"
-            + S.RESET_ALL
-            + S.DIM
-            + S.BRIGHT
+            + Style.RESET_ALL
+            + Style.DIM
+            + Style.BRIGHT
             + "3"
-            + S.RESET_ALL
-            + S.DIM
+            + Style.RESET_ALL
+            + Style.DIM
             + "4"
-            + S.RESET_ALL,
+            + Style.RESET_ALL,
         ),
     ],
 )
@@ -88,9 +101,9 @@ def test_strict_parsing(text):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<b>", S.BRIGHT),
-        ("<Y><b></b>", B.YELLOW + S.BRIGHT + S.RESET_ALL + B.YELLOW),
-        ("<b><b></b>", S.BRIGHT + S.BRIGHT + S.RESET_ALL + S.BRIGHT),
+        ("<b>", Style.BRIGHT),
+        ("<Y><b></b>", Back.YELLOW + Style.BRIGHT + Style.RESET_ALL + Back.YELLOW),
+        ("<b><b></b>", Style.BRIGHT + Style.BRIGHT + Style.RESET_ALL + Style.BRIGHT),
     ],
 )
 def test_permissive_parsing(text, expected):
@@ -100,22 +113,22 @@ def test_permissive_parsing(text, expected):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<red>foo</>", F.RED + "foo" + S.RESET_ALL),
+        ("<red>foo</>", Fore.RED + "foo" + Style.RESET_ALL),
         (
             "<green><bold>bar</></green>",
-            F.GREEN + S.BRIGHT + "bar" + S.RESET_ALL + F.GREEN + S.RESET_ALL,
+            Fore.GREEN + Style.BRIGHT + "bar" + Style.RESET_ALL + Fore.GREEN + Style.RESET_ALL,
         ),
         (
             "a<yellow>b<b>c</>d</>e",
             "a"
-            + F.YELLOW
+            + Fore.YELLOW
             + "b"
-            + S.BRIGHT
+            + Style.BRIGHT
             + "c"
-            + S.RESET_ALL
-            + F.YELLOW
+            + Style.RESET_ALL
+            + Fore.YELLOW
             + "d"
-            + S.RESET_ALL
+            + Style.RESET_ALL
             + "e",
         ),
     ],
@@ -127,8 +140,8 @@ def test_autoclose(text, expected):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        (r"<red>foo\</red>bar</red>", F.RED + "foo</red>bar" + S.RESET_ALL),
-        (r"<red>foo\<red>bar</red>", F.RED + "foo<red>bar" + S.RESET_ALL),
+        (r"<red>foo\</red>bar</red>", Fore.RED + "foo</red>bar" + Style.RESET_ALL),
+        (r"<red>foo\<red>bar</red>", Fore.RED + "foo<red>bar" + Style.RESET_ALL),
         (r"\<red>\</red>", "<red></red>"),
         (r"foo\</>bar\</>baz", "foo</>bar</>baz"),
     ],
