@@ -1,7 +1,5 @@
 import pytest
-from colorama import Back as B
-from colorama import Fore as F
-from colorama import Style as S
+from colorama import Back, Fore, Style
 
 from .conftest import parse
 
@@ -9,10 +7,10 @@ from .conftest import parse
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<bg red>1</bg red>", B.RED + "1" + S.RESET_ALL),
-        ("<bg BLACK>1</bg BLACK>", B.BLACK + "1" + S.RESET_ALL),
-        ("<bg light-green>1</bg light-green>", B.LIGHTGREEN_EX + "1" + S.RESET_ALL),
-        ("<bg LIGHT-MAGENTA>1</bg LIGHT-MAGENTA>", B.LIGHTMAGENTA_EX + "1" + S.RESET_ALL),
+        ("<bg red>1</bg red>", Back.RED + "1" + Style.RESET_ALL),
+        ("<bg BLACK>1</bg BLACK>", Back.BLACK + "1" + Style.RESET_ALL),
+        ("<bg light-green>1</bg light-green>", Back.LIGHTGREEN_EX + "1" + Style.RESET_ALL),
+        ("<bg LIGHT-MAGENTA>1</bg LIGHT-MAGENTA>", Back.LIGHTMAGENTA_EX + "1" + Style.RESET_ALL),
     ],
 )
 def test_background_colors(text, expected):
@@ -22,10 +20,10 @@ def test_background_colors(text, expected):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<fg yellow>1</fg yellow>", F.YELLOW + "1" + S.RESET_ALL),
-        ("<fg BLUE>1</fg BLUE>", F.BLUE + "1" + S.RESET_ALL),
-        ("<fg light-white>1</fg light-white>", F.LIGHTWHITE_EX + "1" + S.RESET_ALL),
-        ("<fg LIGHT-CYAN>1</fg LIGHT-CYAN>", F.LIGHTCYAN_EX + "1" + S.RESET_ALL),
+        ("<fg yellow>1</fg yellow>", Fore.YELLOW + "1" + Style.RESET_ALL),
+        ("<fg BLUE>1</fg BLUE>", Fore.BLUE + "1" + Style.RESET_ALL),
+        ("<fg light-white>1</fg light-white>", Fore.LIGHTWHITE_EX + "1" + Style.RESET_ALL),
+        ("<fg LIGHT-CYAN>1</fg LIGHT-CYAN>", Fore.LIGHTCYAN_EX + "1" + Style.RESET_ALL),
     ],
 )
 def test_foreground_colors(text, expected):
@@ -35,9 +33,9 @@ def test_foreground_colors(text, expected):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<fg #ff0000>1</fg #ff0000>", "\x1b[38;2;255;0;0m" "1" + S.RESET_ALL),
-        ("<bg #00A000>1</bg #00A000>", "\x1b[48;2;0;160;0m" "1" + S.RESET_ALL),
-        ("<fg #F12>1</fg #F12>", "\x1b[38;2;241;47;18m" "1" + S.RESET_ALL),
+        ("<fg #ff0000>1</fg #ff0000>", "\x1b[38;2;255;0;0m" "1" + Style.RESET_ALL),
+        ("<bg #00A000>1</bg #00A000>", "\x1b[48;2;0;160;0m" "1" + Style.RESET_ALL),
+        ("<fg #F12>1</fg #F12>", "\x1b[38;2;241;47;18m" "1" + Style.RESET_ALL),
     ],
 )
 def test_8bit_colors(text, expected):
@@ -47,10 +45,10 @@ def test_8bit_colors(text, expected):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<fg #ff0000>1</fg #ff0000>", "\x1b[38;2;255;0;0m" "1" + S.RESET_ALL),
-        ("<bg #00A000>1</bg #00A000>", "\x1b[48;2;0;160;0m" "1" + S.RESET_ALL),
-        ("<fg #F12>1</fg #F12>", "\x1b[38;2;241;47;18m" "1" + S.RESET_ALL),
-        ("<bg #BEE>1</bg #BEE>", "\x1b[48;2;190;235;238m" "1" + S.RESET_ALL),
+        ("<fg #ff0000>1</fg #ff0000>", "\x1b[38;2;255;0;0m" "1" + Style.RESET_ALL),
+        ("<bg #00A000>1</bg #00A000>", "\x1b[48;2;0;160;0m" "1" + Style.RESET_ALL),
+        ("<fg #F12>1</fg #F12>", "\x1b[38;2;241;47;18m" "1" + Style.RESET_ALL),
+        ("<bg #BEE>1</bg #BEE>", "\x1b[48;2;190;235;238m" "1" + Style.RESET_ALL),
     ],
 )
 def test_hex_colors(text, expected):
@@ -60,8 +58,8 @@ def test_hex_colors(text, expected):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<fg 200>1</fg 200>", "\x1b[38;5;200m" "1" + S.RESET_ALL),
-        ("<bg 49>1</bg 49>", "\x1b[48;5;49m" "1" + S.RESET_ALL),
+        ("<fg 200>1</fg 200>", "\x1b[38;5;200m" "1" + Style.RESET_ALL),
+        ("<bg 49>1</bg 49>", "\x1b[48;5;49m" "1" + Style.RESET_ALL),
     ],
 )
 def test_rgb_colors(text, expected):
@@ -73,8 +71,14 @@ def test_rgb_colors(text, expected):
     [
         (
             "<red><b><bg #00A000>1</bg #00A000></b></red>",
-            F.RED + S.BRIGHT + "\x1b[48;2;0;160;0m"
-            "1" + S.RESET_ALL + F.RED + S.BRIGHT + S.RESET_ALL + F.RED + S.RESET_ALL,
+            Fore.RED + Style.BRIGHT + "\x1b[48;2;0;160;0m"
+            "1"
+            + Style.RESET_ALL
+            + Fore.RED
+            + Style.BRIGHT
+            + Style.RESET_ALL
+            + Fore.RED
+            + Style.RESET_ALL,
         ),
         (
             "<bg 100><fg 200>1</fg 200></bg 100>",
@@ -97,17 +101,17 @@ def test_nested(text, expected):
 @pytest.mark.parametrize(
     "text, expected",
     [
-        ("<r>2 > 1</r>", F.RED + "2 > 1" + S.RESET_ALL),
-        ("<r>1 < 2</r>", F.RED + "1 < 2" + S.RESET_ALL),
-        ("<r>1 </ 2</r>", F.RED + "1 </ 2" + S.RESET_ALL),
-        ("{: <10}<r>1</r>", "{: <10}" + F.RED + "1" + S.RESET_ALL),
-        ("{: </10}<r>1</r>", "{: </10}" + F.RED + "1" + S.RESET_ALL),
-        ("<r>1</r>{: >10}", F.RED + "1" + S.RESET_ALL + "{: >10}"),
-        ("<1<r>2</r>3>", "<1" + F.RED + "2" + S.RESET_ALL + "3>"),
-        ("</1<r>2</r>3>", "</1" + F.RED + "2" + S.RESET_ALL + "3>"),
-        ("<1<r>2 < 3</r>4>", "<1" + F.RED + "2 < 3" + S.RESET_ALL + "4>"),
-        ("<1<r>2 </ 3</r>4>", "<1" + F.RED + "2 </ 3" + S.RESET_ALL + "4>"),
-        ("<1<r>3 > 2</r>4>", "<1" + F.RED + "3 > 2" + S.RESET_ALL + "4>"),
+        ("<r>2 > 1</r>", Fore.RED + "2 > 1" + Style.RESET_ALL),
+        ("<r>1 < 2</r>", Fore.RED + "1 < 2" + Style.RESET_ALL),
+        ("<r>1 </ 2</r>", Fore.RED + "1 </ 2" + Style.RESET_ALL),
+        ("{: <10}<r>1</r>", "{: <10}" + Fore.RED + "1" + Style.RESET_ALL),
+        ("{: </10}<r>1</r>", "{: </10}" + Fore.RED + "1" + Style.RESET_ALL),
+        ("<r>1</r>{: >10}", Fore.RED + "1" + Style.RESET_ALL + "{: >10}"),
+        ("<1<r>2</r>3>", "<1" + Fore.RED + "2" + Style.RESET_ALL + "3>"),
+        ("</1<r>2</r>3>", "</1" + Fore.RED + "2" + Style.RESET_ALL + "3>"),
+        ("<1<r>2 < 3</r>4>", "<1" + Fore.RED + "2 < 3" + Style.RESET_ALL + "4>"),
+        ("<1<r>2 </ 3</r>4>", "<1" + Fore.RED + "2 </ 3" + Style.RESET_ALL + "4>"),
+        ("<1<r>3 > 2</r>4>", "<1" + Fore.RED + "3 > 2" + Style.RESET_ALL + "4>"),
     ],
 )
 def test_tricky_parse(text, expected):
