@@ -1,5 +1,5 @@
+import inspect
 import logging
-import sys
 
 from loguru import logger
 
@@ -15,8 +15,8 @@ class InterceptHandler(logging.Handler):
             level = record.levelno
 
         # Find caller from where originated the logged message.
-        frame, depth = sys._getframe(6), 6
-        while frame and frame.f_code.co_filename == logging.__file__:
+        frame, depth = inspect.currentframe(), 0
+        while frame and (depth == 0 or frame.f_code.co_filename == logging.__file__):
             frame = frame.f_back
             depth += 1
 
@@ -101,7 +101,7 @@ def test_exception(writer):
         logger.add(writer, format="{message}")
 
         try:
-            1 / 0
+            1 / 0  # noqa: B018
         except Exception:
             logging_logger.exception("Oops...")
 
